Module args
fre
0.4.1
Module args
Module Items
Structs
Enums
Functions
In crate fre
fre
Module
args
Structs

Cli
Janitor
Args
Stats
Args
Update
Args
Enums

Sort
Method
Functions

default_
store
Return a path to a store file in the default location. Uses filename as the name of the file if it is not
None
.
get_
store_
path
Given the argument matches, return the path of the store file.